@@ -26,17 +26,16 @@ def wrap_ptr_class(struct, constructor, destructor, classname=None):
                 super(WrapperClass, self).__init__(val)
             else:
                 super(WrapperClass, self).__init__(constructor())
-            #~ print val, self.value
         def __del__(self):
             destructor(self)
             self.value = None
         def __getattr__(self, name):
-            return getattr(ctypes.cast(self, ctypes.POINTER(struct)).contents, name)
+            return getattr(ctypes.cast(self.value, ctypes.POINTER(struct)).contents, name)
         def __setattr__(self, name, value):
-            if name == 'value':
+            if name == 'value' or name.startswith('_'):
                 super(WrapperClass, self).__setattr__(name, value)
             else:
-                setattr(ctypes.cast(self, ctypes.POINTER(struct)).contents, name, value)
+                setattr(ctypes.cast(self.value, ctypes.POINTER(struct)).contents, name, value)
     WrapperClass.__name__ = classname or struct.__name__.lstrip('_')
     return WrapperClass
 
