@@ -33,10 +33,6 @@ class TestSimple(unittest.TestCase):
         res = self.testPing()
         self.assertRaises(ImageMagickException, res.makeThumbnail, 10, 10)
 
-    def testPingExc2(self):
-        res = self.testPing()
-        self.assertRaises(ImageMagickException, res.applyComposite, CompositeOp.Over, self.testRead2(), 100, 110)
-
     def testRead2(self):
         res = Image.read(self.samplepath2)
         self.assertTrue(res)
